@@ -17,12 +17,13 @@
 */
 
 
-#ifndef __ABOUT_H__
-#define __ABOUT_H__
+#ifndef PLOUF_H__
+#define PLOUF_H__
 
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+
+void get_about_dialog();
 
-void about_gtktalog (GtkWidget * w, gpointer data);
 
 #endif
