@@ -16,33 +16,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef __ADDISK_H__
-#define __ADDISK_H__
+#ifndef CHLAGAGA_H__
+#define CHLAGAGA_H__
 
-#include "config_common.h"
+#include <unistd.h>
+#include "data.h"
 
-guint du_s (gchar * path);
-gboolean eject_disk(CONFIG *my_config);
-gboolean mount_disk(CONFIG *my_config);
-gboolean umount_disk(CONFIG *my_config);
+pid_t current_pid;
 
-gint get_thread_status ();
-void reinit_thread_status ();
-void set_thread_status_to_running ();
-void set_thread_status_to_ended ();
-
-void do_not_forget_to_umount (gboolean gb);
-void do_not_forget_to_mount (gboolean gb);
-void set_local_disk_name (gchar * s);
-void set_local_folder_name (gchar * s);
-void set_added_disk (gboolean gb);
-
-gint my_timeout (gpointer data);
-
-gchar *read_information (gchar * file);
-void create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
-			 gboolean getInformation);
-void *start_thread_scan (void *arg);
-void finish_normal_scan (int sig);
+int start_add_disk(char *foldername, char* diskname);
+void fast_add_disk(GtkWidget *w, gpointer data);
+void create_folder_tree(Folder *folder,gchar *path);
+unsigned char disk_path_size;
 
 #endif
+
