@@ -16,34 +16,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef __EDIT_H__
-#define __EDIT_H__
+#ifndef HMMM_DES_DONUTS_H__
+#define HMMM_DES_DONUTS_H__
 
-#include "config_common.h"
-
-typedef struct
-{
-  GtkWidget *edit_window;
-  GtkWidget *fold_entry;
-  GtkWidget *cat_box;
-  GtkWidget *cat_combo;
-  GtkWidget *cat_ed;
-  GtkWidget *desc_combo;
-  GtkWidget *recursive_category;
-  GtkWidget *recursive_description;
-  gpointer tmpdata;
-
-}
-EDIT_WIDGETS;
-
-gboolean is_file_with_the_same_name(GNode *gn, gpointer data);
-gboolean _change_category(GNode *gn, gpointer data);
-gboolean _change_description(GNode *gn, gpointer data);
-gint description_add(GPtrArray *description_array, gchar *text);
-void delete_folder(GtkWidget *w, CONFIG *my_config);
-void update_category_combo(CONFIG *my_config);
-void edit_folder(GtkWidget *w, gpointer data);
-void update_disk(GtkWidget *w, gpointer data);
+void edit_folder(GtkWidget *w);
+void list_folder(Folder *folder);
+void update_cat_box();
+void delete_folder(GtkWidget *w);
+int file_exist_in(Folder *folder, char *name, GtkWidget *widget);
+int folder_exist_in(Folder *folder, char *name, GtkWidget *widget);
 
 
 #endif
+
