@@ -16,25 +16,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef __INTERFACE_H__
-#define __INTERFACE_H__
+#ifndef WHAT_DO_YOU_WANT_H__
+#define WHAT_DO_YOU_WANT_H__
+
+#include <gtk/gtk.h>
+#include "data.h"
+
+GtkWidget *window;
+GtkWidget *clist;
+GtkWidget *tree;
+
+typedef struct
+{
+  gboolean scanned;
+  gchar *path;
+  Folder *folder;
+} DirNode;
+
+GtkWidget *create_tree (void);
+
+void clear_all(GtkWidget *w, gpointer data);
+void resolve_link(Folder *folder,char *link_path, char *cur_path, int i);
+
+void fast_save(GtkWidget *w, gpointer data);
+void open_cat(GtkWidget *w, gpointer data);
+void save_cat(GtkWidget *w, gpointer data);
+void quit_prog(GtkWidget *w, gpointer data);
 
-#include <config.h>
-#include <gnome.h>
-#include "config_common.h"
 
-void ctree_window_add(GtkWidget *ctree);
-void traverse_add_dir_to_clist(GNode *gn, gpointer data);
-void catalog_set_selected_folder(GNode *gn);
-void traverse_add_file_to_clist(GNode *gn, gpointer data);
-void list_folder(GNode *parent);
-EXTENSIONS *find_extension (gchar * file);
-void fin_fils(int sig);
-void clist_pressed(GtkWidget *wid, GdkEventButton *event, gpointer data);
-GtkWidget *create_list();
-void tree_pressed(GtkWidget *wid, GdkEventButton *event, gpointer data);
-void update_tree(FOLDER *racine);
-void clean_description (FOLDER *racine);
-void build_gui();
 
 #endif
