@@ -15,21 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#ifndef __LOADCAT_H__
-#define __LOADCAT_H__
-#include <zlib.h>
+#ifndef JE_CLICK_SUR_ON_DANS_MENU_POMME_H__
+#define JE_CLICK_SUR_ON_DANS_MENU_POMME_H__
 
-#include "config_common.h"
+int load_cat_from_file(char *filename);
 
-#ifdef CATALOG2
-	#include "load_oldcat.h"
-#endif
-
-GString *read_gstring(int fh);
-GString *gzread_gstring(gzFile fh);
-FILE_DATA *read_filedata(gzFile gzfh, int fh);
-void load_folder_tree(FOLDER *racine, gzFile gzcatalog, int catalog);
-GPtrArray *load_gptrarray_of_gstrings(gzFile gzfh, int fh);
-int load_cat_from_file(char *filename, FOLDER *racine);
 
 #endif
