@@ -15,15 +15,9 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#ifndef __SAVECAT_H__
-#define __SAVECAT_H__
+#ifndef TRUCMUCHE_H__
+#define TRUCMUCHE_H__
 
-#include "config_common.h"
-
-void fwrite_gstring (GString * g, FILE * fh);
-void fwrite_filedata (FILE_DATA * d, FILE * fh);
-void fwrite_subdir (GNode * gn);
-void fwrite_gnode (GNode * gn, gpointer data);
-int save_cat_to_file (char *filename, FOLDER * racine);
+int save_cat_to_file(char *filename);
 
 #endif
