@@ -16,31 +16,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __SEARCH_H__
-#define __SEARCH_H__
+#ifndef TAGADA_TZOIN_TZOIN_POUET_POUET_H__
+#define TAGADA_TZOIN_TZOIN_POUET_POUET_H__
 
-#include <config.h>
-#include <gnome.h>
-#include <time.h>
-/*#include "data.h"*/
-#include "config_common.h"
+#include <gtk/gtk.h>
+#include "data.h"
 
-typedef struct
-{
+typedef struct{
   unsigned char val;
-  FOLDER *folder;
-  char *data[7];		//cotient toutes les infos de Folder en char
-}
-search_info;
+  Folder *folder;
+  char *data[7];//cotient toutes les infos de Folder en char
+}search_info;
+
+void open_result_dialog(GtkWidget *w);
+void search_in_data(Folder *folder, gchar *filename,gchar *infostring, int in_file, int in_folder, int sensitive, gchar *cur_disk, gchar *cur_path);
+void open_search_dialog(GtkWidget *w);
+void list_folder(Folder *folder);
+void affiche_files();
+void affiche_row(search_info *info);
+
 
-GNode *find_node_with_parent(GNode *parent, gchar *name, gboolean case_sensitive, FOLDER * racine);
-gboolean find_files(GNode *gn, gpointer data);
-void start_search(FOLDER * racine);
-void start_extended_search(GtkWidget *w, gpointer data);
-void start_simple_search(GtkWidget *w, gpointer data);
-void use_calendar1(GtkWidget *w, gpointer data);
-void use_calendar2(GtkWidget *w, gpointer data);
-void sort_list(GtkWidget *wid, gint column, gpointer data);
-void create_search_dialog(FOLDER *racine);
 
 #endif
