@@ -16,10 +16,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef __SELECTDIR_H__
-#define __SELECTDIR_H__
-
-#include "config_common.h"
-
-void show_select_dir_win (GtkWidget * widget, CONFIG * my_config);
+#ifndef CAMION_POUBELL_H__
+#define CAMION_POUBELL_H__
+void show_select_dir_win();
 #endif
