@@ -36,7 +36,6 @@ WINDOW *date_pad;
 WINDOW *cat_pad;
 WINDOW *desc_pad;
 
-Folder *curent_folder;
 int file_pad_size;
 int size_pad_size;
 int date_pad_size;
@@ -45,7 +44,6 @@ int desc_pad_size;
 int selected;
 int last_selected;
 int decalage;
-char *path;
 
 char *blanck_line;
 
@@ -101,16 +99,16 @@ void update_browser_description(WINDOW *parent_pad,Folder *folder,int update)
   if(is_racine(folder) != 0)
     {
       back = 2;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6; 
      if(decalage < -1) decalage = -1; 
     }
   else
     {
       back = 1;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6;
       if(decalage < 0) decalage = 0;
     }
@@ -234,16 +232,16 @@ void update_browser_categorie(WINDOW *parent_pad,Folder *folder,int update)
   if(is_racine(folder) != 0)
     {
       back = 2;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6; 
      if(decalage < -1) decalage = -1; 
     }
   else
     {
       back = 1;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6;
       if(decalage < 0) decalage = 0;
     }
@@ -352,16 +350,16 @@ void update_browser_date(WINDOW *parent_pad,Folder *folder,int update)
   if(is_racine(folder) != 0)
     {
       back = 2;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6; 
      if(decalage < -1) decalage = -1; 
     }
   else
     {
       back = 1;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6;
       if(decalage < 0) decalage = 0;
     }
@@ -473,16 +471,16 @@ void update_browser_size(WINDOW *parent_pad,Folder *folder, int update)
   if(is_racine(folder) != 0)
     {
       back = 2;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6; 
      if(decalage < -1) decalage = -1; 
     }
   else
     {
       back = 1;
-      while(selected -decalage +back> hauteur -6) decalage = decalage +5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage +5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6;
       if(decalage < 0) decalage = 0;
     }
@@ -599,16 +597,16 @@ void update_browser_file(WINDOW *parent_pad,Folder *folder, int update)
   if(is_racine(folder) != 0)
     {
       back = 2;
-      while(selected -decalage +back> hauteur -6) decalage = decalage+5;
-      while(selected -decalage <0) decalage = decalage -5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage+5;
+      if(selected -decalage <0) decalage = decalage -5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6; 
      if(decalage < -1) decalage = -1; 
     }
   else
     {
       back = 1;
-      while(selected -decalage +back> hauteur -6) decalage = decalage + 5;
-      while(selected -decalage <0) decalage = decalage - 5; 
+      if(selected -decalage +back> hauteur -6) decalage = decalage + 5;
+      if(selected -decalage <0) decalage = decalage - 5; 
       if((decalage + hauteur -6) > (folder->nb_files +folder->nb_folders)) decalage = folder->nb_files +folder->nb_folders -hauteur +6;
       if(decalage < 0) decalage = 0;
     }
@@ -755,10 +753,11 @@ void open_cat_browser()
 {
   WINDOW *pad, *path_pad, *down_pad;
   int key;
+  Folder *curent_folder;
   int changedir;
   int update;
+  char *path;
   int i;
-  Folder *tmp_fold;
 
   blanck_line = (char *)malloc(largeur+1*sizeof(char));
   for(i=0;i<largeur;i++) blanck_line[i] = ' ';
@@ -781,10 +780,10 @@ void open_cat_browser()
   path_pad = newpad(3,largeur);
   box(path_pad,0,0);
   prefresh(path_pad,0,0,0,0,3,largeur);
-  wbkgd(file_pad, A_NORMAL);
-  mvwaddstr(path_pad, 1, 1," NCatalog v0.02   Press F12 to display some help.");
+  wbkgd(file_pad, A_BLINK);
+  mvwaddstr(path_pad, 1, 1,"    Use F12 to display some help.");
   prefresh(path_pad,1,1,1,1,1,largeur-2);
-  mvwaddstr(path_pad, 1, 1,"                                                   ");
+  mvwaddstr(path_pad, 1, 1,"                                 ");
   wbkgd(file_pad, A_NORMAL);
   curent_folder = &racine;
   
@@ -805,12 +804,8 @@ void open_cat_browser()
       update = 0;
       if(changedir == 1)
 	{
-	  selected = -1;
-	  last_selected = 0;
-	  decalage = -2;
-	}
-      else if(changedir == 2)
-	{
+	  if(is_racine(curent_folder) == 0) selected = 0;
+	  else selected = -1;
 	  last_selected = 0;
 	  decalage = -2;
 	}
@@ -863,18 +858,16 @@ void open_cat_browser()
 	  update = 1;
 	}
 
-      delwin(file_pad);
-      delwin(size_pad);
-      delwin(date_pad);
-      delwin(cat_pad);
-      delwin(desc_pad);
-
       file_pad = newpad(hauteur -5,file_pad_size);
       size_pad = newpad(hauteur -5,size_pad_size);
       date_pad = newpad(hauteur -5,date_pad_size);
       cat_pad  = newpad(hauteur -5,cat_pad_size);
       desc_pad  = newpad(hauteur -5,desc_pad_size);
- 
+  /*    wclear (file_pad);
+      wclear (size_pad);
+      wclear (date_pad);
+      wclear (cat_pad);
+      wclear (desc_pad);*/
       changedir = 0;
       while(changedir == 0)
 	{
@@ -882,8 +875,7 @@ void open_cat_browser()
 	  update_browser_size(pad,curent_folder,update);
 	  update_browser_date(pad,curent_folder,update);
 	  update_browser_categorie(pad,curent_folder,update);
-	  update_browser_description(pad,curent_folder,update);
-	 // prefresh(path_pad,0,0,0,0,3,largeur); 
+	  update_browser_description(pad,curent_folder,update); 
 	  update = 0;
 	  noecho();
 	  keypad(stdscr,TRUE);
@@ -912,23 +904,14 @@ void open_cat_browser()
 	      affiche_short_info(down_pad,curent_folder,resize_pad);
 	      break;
 	    case KEY_F(7):
-       	      tmp_fold = curent_folder;
 	      start_search_function();
 	      put_line(pad,file_pad_size +1);
 	      put_line(pad,file_pad_size +1+size_pad_size+1); 
 	      put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1); 
 	      put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1+cat_pad_size+1); 
 	      prefresh(path_pad,0,0,0,0,3,largeur);
-	      
-	      if (tmp_fold != curent_folder)
-		{
-		  mvwaddstr(path_pad, 1, 2, path);
-		  box(path_pad,0,0);
-		  prefresh(path_pad,0,0,0,0,3,largeur);
-		}
 	      update = 1;
 	      break; 
-
 	    case 'p':
 	    case KEY_RIGHT:
 	      changedir = -1;
@@ -945,7 +928,7 @@ void open_cat_browser()
 	      endwin();
 	      exit(1);
 	    case KEY_F(12):
-	      display_information(help,"  NCatalog help:");
+	      display_information(help);
 	      prefresh(pad,0,0,0,0,hauteur-1,largeur);
 	      put_line(pad,file_pad_size +1);
 	      put_line(pad,file_pad_size +1+size_pad_size+1); 
@@ -954,59 +937,16 @@ void open_cat_browser()
 	      prefresh(path_pad,0,0,0,0,3,largeur);
 	      changedir = 1;
 	      break;
-	    case ' ':
-	        if(selected == -1)
-		{
-		  display_information(curent_folder->information,curent_folder->name);
-		  prefresh(pad,0,0,0,0,hauteur-1,largeur);
-		  put_line(pad,file_pad_size +1);
-		  put_line(pad,file_pad_size +1+size_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1+cat_pad_size+1); 
-		  prefresh(path_pad,0,0,0,0,3,largeur);
-		  changedir = 2;  
-		}
-	     else if (selected < curent_folder->nb_folders)
-		{
-		  display_information(curent_folder->folders[selected].information,curent_folder->folders[selected].name);
-		  prefresh(pad,0,0,0,0,hauteur-1,largeur);
-		  put_line(pad,file_pad_size +1);
-		  put_line(pad,file_pad_size +1+size_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1+cat_pad_size+1); 
-		  prefresh(path_pad,0,0,0,0,3,largeur);
-		  changedir = 2; 
-		}
-	      else 
-		{
-		  display_information(curent_folder->files[selected -curent_folder->nb_folders].information,curent_folder->files[selected -curent_folder->nb_folders].name);
-		  prefresh(pad,0,0,0,0,hauteur-1,largeur);
-		  put_line(pad,file_pad_size +1);
-		  put_line(pad,file_pad_size +1+size_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1); 
-		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1+cat_pad_size+1); 
-		  prefresh(path_pad,0,0,0,0,3,largeur);
-		  changedir = 1;
-		}	     
-	      break;
 	    case '\n': 
 	      if(selected == -1)
 		{
 		  path[strlen(path)-(strlen(curent_folder->name) +1)] = '\0';
-		  //je recheche le repertoire parent pour le selectionner; 
-		  selected = 0;
-		  while(strcmp(curent_folder->name,curent_folder->parent->folders[selected].name) != 0) selected++;
 		  curent_folder = curent_folder->parent;
-		  if(curent_folder == &racine)
-		    {
-		      path[0] = '\0';
-		      wbkgd(file_pad, A_REVERSE);
-		    }
+		  if(curent_folder == &racine) path[0] = '\0';
 		  wclear(path_pad);
 		  mvwaddstr(path_pad, 1, 2, path);
 		  box(path_pad,0,0);
 		  prefresh(path_pad,0,0,0,0,3,largeur);
-		  changedir = 2;
 		} 
 	      else if (selected < curent_folder->nb_folders)
 		{
@@ -1024,8 +964,18 @@ void open_cat_browser()
 		  mvwaddstr(path_pad, 1, 2, path);
 		  box(path_pad,0,0);
 		  prefresh(path_pad,0,0,0,0,3,largeur);
-		  changedir = 1;
 		}
+	      else
+		{
+		  display_information(curent_folder->files[selected].information);
+		  prefresh(pad,0,0,0,0,hauteur-1,largeur);
+		  put_line(pad,file_pad_size +1);
+		  put_line(pad,file_pad_size +1+size_pad_size+1); 
+		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1); 
+		  put_line(pad,file_pad_size +1+size_pad_size+1+date_pad_size+1+cat_pad_size+1); 
+		  prefresh(path_pad,0,0,0,0,3,largeur);
+		}
+	      changedir = 1;
 	      break;          
 	    case KEY_UP:
 	      if(is_racine(curent_folder) == 0)
