@@ -30,11 +30,9 @@
 extern int hauteur;
 extern int largeur;
 extern char *help;
-extern Folder *curent_folder;
+
 extern search_info *search_files;
 extern int nb_files;
-extern int selected;
-extern char *path;
 
 WINDOW *sfile_pad;
 WINDOW *ssize_pad;
@@ -76,7 +74,7 @@ void search_blanck_pad(WINDOW *pad)
 }
 
 
-void search_update_browser_description(int update)
+void search_update_browser_description(WINDOW *parent_pad,Folder *folder,int update)
 {
  // WINDOW *pad;
   int i;
@@ -124,7 +122,7 @@ void search_update_browser_description(int update)
 	}
     }
 
-    //on efface l'ancien fichier selection, et on le met comme il faut : BOLD ou NORMAL
+    //on efface l'ancien fichier selection, et on le met comme il faut : BOLR ou NORMAL
   if(nb_files > 0)
     {
       if(is_file(search_files[last_sselected].folder) == 1)
@@ -151,7 +149,7 @@ void search_update_browser_description(int update)
 
 
 
-void search_update_browser_categorie(int update)
+void search_update_browser_categorie(WINDOW *parent_pad,Folder *folder,int update)
 {
  // WINDOW *pad;
   int i;
@@ -215,7 +213,7 @@ void search_update_browser_categorie(int update)
 }
 
 
-void search_update_browser_path(int update)
+void search_update_browser_path(WINDOW *parent_pad,Folder *folder,int update)
 {
  // WINDOW *pad;
   int i;
@@ -283,7 +281,7 @@ void search_update_browser_path(int update)
 }
 
 
-void search_update_browser_date(int update)
+void search_update_browser_date(WINDOW *parent_pad,Folder *folder,int update)
 {
  // WINDOW *pad;
   int i;
@@ -351,7 +349,7 @@ void search_update_browser_date(int update)
 
 
 
-void search_update_browser_size(int update)
+void search_update_browser_size(WINDOW *parent_pad,Folder *folder, int update)
 {
   //WINDOW *pad;
   int i;
@@ -420,7 +418,7 @@ void search_update_browser_size(int update)
 
 
 
-void search_update_browser_file(int update)
+void search_update_browser_file(WINDOW *parent_pad,Folder *folder, int update)
 {
 //  WINDOW *sfile_pad;
 
@@ -487,7 +485,7 @@ void search_update_browser_file(int update)
 
 
 
-void search_affiche_short_info(WINDOW *pad,char pad_num)
+void search_affiche_short_info(WINDOW *pad,Folder *curent_folder,char pad_num)
 {
   char *data;
   mvwaddstr(pad, 0, 1, blanck_line); 
@@ -534,6 +532,7 @@ int open_search_result()
 {
   WINDOW *pad, *down_pad;
   int key;
+  Folder *curent_folder;
   int changedir;
   int update;
   int i;
@@ -556,7 +555,7 @@ int open_search_result()
   prefresh(pad,0,0,0,0,hauteur,largeur);
   
   down_pad = newpad(1,largeur);
-  search_affiche_short_info(down_pad,ressize_pad);
+  search_affiche_short_info(down_pad,curent_folder,ressize_pad);
   prefresh(down_pad,0,0,hauteur -1,0,hauteur ,largeur);
   
 
@@ -642,12 +641,12 @@ int open_search_result()
       changedir = 0;
       while(changedir == 0)
 	{
-	  search_update_browser_file(update);
-	  search_update_browser_size(update);
-	  search_update_browser_date(update);
-	  search_update_browser_path(update);
-	  search_update_browser_categorie(update);
-	  search_update_browser_description(update); 
+	  search_update_browser_file(pad,curent_folder,update);
+	  search_update_browser_size(pad,curent_folder,update);
+	  search_update_browser_date(pad,curent_folder,update);
+	  search_update_browser_path(pad,curent_folder,update);
+	  search_update_browser_categorie(pad,curent_folder,update);
+	  search_update_browser_description(pad,curent_folder,update); 
 	  update = 0;
 	  noecho();
 	  keypad(stdscr,TRUE);
@@ -657,27 +656,27 @@ int open_search_result()
 	    {
 	    case KEY_F(1):
 	      ressize_pad = 'f';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(2):
 	      ressize_pad = 's';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(3):
 	      ressize_pad = 'd';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(4):
 	      ressize_pad = 'p';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(5):
 	      ressize_pad = 'c';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(6):
 	      ressize_pad = 'e';
-	      search_affiche_short_info(down_pad,ressize_pad);
+	      search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 	      break;
 	    case KEY_F(7):
 	      delwin (down_pad);
@@ -685,7 +684,7 @@ int open_search_result()
 	      return 2;
 	      break; 
 	    case KEY_F(12):
-	       display_information(help,"  NCatalog help:");
+	       display_information(help);
 	      prefresh(pad,0,0,0,0,hauteur,largeur);
 	      search_put_line(pad,sfile_pad_size +1);
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1); 
@@ -693,12 +692,12 @@ int open_search_result()
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1+spath_pad_size+1+sdate_pad_size+1); 
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1+sdate_pad_size+1+spath_pad_size+1+scat_pad_size+1);
 	      update = 1;
-	      search_update_browser_file(update);
-	      search_update_browser_size(update);
-	      search_update_browser_date(update);
-	      search_update_browser_path(update);
-	      search_update_browser_categorie(update);
-	      search_update_browser_description(update); 
+	      search_update_browser_file(pad,curent_folder,update);
+	      search_update_browser_size(pad,curent_folder,update);
+	      search_update_browser_date(pad,curent_folder,update);
+	      search_update_browser_path(pad,curent_folder,update);
+	      search_update_browser_categorie(pad,curent_folder,update);
+	      search_update_browser_description(pad,curent_folder,update); 
 	      break;        
 	    case 'p':
 	    case KEY_RIGHT:
@@ -712,8 +711,8 @@ int open_search_result()
 	      delwin (pad);
 	      delwin (down_pad);
 	      return 10;
-	    case ' ':
-	      display_information(search_files[sselected].folder->information,search_files[sselected].folder->name);
+	    case '\n':
+	      display_information(search_files[sselected].folder->information);
 	      prefresh(pad,0,0,0,0,hauteur,largeur);
 	      search_put_line(pad,sfile_pad_size +1);
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1); 
@@ -721,40 +720,25 @@ int open_search_result()
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1+spath_pad_size+1+sdate_pad_size+1); 
 	      search_put_line(pad,sfile_pad_size +1+ssize_pad_size+1+sdate_pad_size+1+spath_pad_size+1+scat_pad_size+1);
 	      update = 1;
-	      search_update_browser_file(update);
-	      search_update_browser_size(update);
-	      search_update_browser_date(update);
-	      search_update_browser_path(update);
-	      search_update_browser_categorie(update);
-	      search_update_browser_description(update); 
-	      break;  
-	    case '\n':
-	      if(is_file(search_files[sselected].folder) != 0) 
-		{
-		  //pour eviter un grosse taille memoire, je stoque ne met pas la position,
-		  //donc je la recupre maintenant;
-		  selected = 0;
-		  while(strcmp(search_files[sselected].folder->name,search_files[sselected].folder->parent->files[selected].name) != 0) selected++;
-		  selected = selected + search_files[sselected].folder->parent->nb_folders;
-		  curent_folder = search_files[sselected].folder->parent;
-		}
-	      else curent_folder = search_files[sselected].folder;
-	      strcpy(path,search_files[sselected].data);
-	      delwin (down_pad);
-	      delwin (pad);
-	      return 0;
+	      search_update_browser_file(pad,curent_folder,update);
+	      search_update_browser_size(pad,curent_folder,update);
+	      search_update_browser_date(pad,curent_folder,update);
+	      search_update_browser_path(pad,curent_folder,update);
+	      search_update_browser_categorie(pad,curent_folder,update);
+	      search_update_browser_description(pad,curent_folder,update); 
+	      break;        
 	    case KEY_UP:
 	       if(sselected > 0) 
 		{
 		  sselected--;
-		  search_affiche_short_info(down_pad,ressize_pad);
+		  search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 		}
 	      break;
 	    case KEY_DOWN:
 	      if(sselected < (nb_files -1))
 		{
 		  sselected++;
-		  search_affiche_short_info(down_pad,ressize_pad);
+		  search_affiche_short_info(down_pad,curent_folder,ressize_pad);
 		}
 	      break;
 	    case KEY_F(10):
