@@ -18,4 +18,4 @@
 
 
 
-void display_information(char *info, char *titre);
+void display_information(char *info);
